package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`/@`!````$"%```````!``````````$C/````
M`````````$``.``)`$``'``;``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````&QA````````;&$`````````
M`"````````$````&````"&X````````(;F````````AN8```````_%\`````
M``"X<```````````(````````@````8````P;@```````#!N8```````,&Y@
M``````"P`0```````+`!````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````4%L```````!06T```````%!;0```````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"`````````!2Y71D!`````AN````````"&Y@```````(;F``
M`````/@!````````^`$````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````#P````0`
M```4`````P```$=.50`%.]TQYOIKO'_2-6F?.K9D?"68;Q$```!$````!```
M``@````@'!``!4`$ABH"0`"0A@&H0B@`($D@!`NXHCA-N@0&"D0```!%````
M20```$X```!/````5@```%@```!:````70```%\`````````80```&0```!E
M````9@``````````````>_!*:V[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#GQ!
MCL6XC?$.U634?-EQ6!SB1\8!K$OCP/+;TQVZXY)\PN4_+/JA;&"S`8MO:@E#
MUH?YG(%FK\QFQ;F<0$)%U>S$B060.?*+'`P4XI[)U;)QVLWCGC-BV^T,.I<+
M5J2;EJ?=HVM_J9R;X:<""@J*$%>CX/M)````````````````````````````
M``````````<!```2`````````````````````````.L!```2````````````
M`````````````&H"```2`````````````````````````#\"```2````````
M`````````````````'$"```2``````````````````````````L#```2````
M`````````````````````)T````2`````````````````````````(8"```2
M`````````````````````````.4"```2`````````````````````````-T"
M```2`````````````````````````'D````2````````````````````````
M`,0#```2``````````````````````````(!```2````````````````````
M`````*D"```2`````````````````````````)0"```2````````````````
M`````````%D"```2``````````````````````````0#```2````````````
M`````````````"@#```2`````````````````````````&L!```2````````
M`````````````````"L!```2`````````````````````````)L"```2````
M`````````````````````*L````2`````````````````````````+4!```2
M`````````````````````````!@"```2`````````````````````````%`"
M```2`````````````````````````%(!```2````````````````````````
M`"@"```2`````````````````````````$<"```2````````````````````
M`````*(!```2`````````````````````````'\"```2````````````````
M`````````.8!```2`````````````````````````%T#```2````````````
M`````````````+T"```2`````````````````````````%8#```2````````
M`````````````````#D!```2`````````````````````````!L#```2````
M`````````````````````!$````@`````````````````````````$(````2
M`````````````````````````-D````2``````````````````````````0"
M```2`````````````````````````*X!```2````````````````````````
M`(@````2`````````````````````````&`!```2````````````````````
M`````#0````2``````````````````````````P!```2````````````````
M`````````,0"```2`````````````````````````)<!```2````````````
M`````````````.8````2`````````````````````````'<"```2````````
M`````````````````-\!```2`````````````````````````$<#```2````
M`````````````````````"\#```2`````````````````````````'D!```2
M`````````````````````````$\#```2`````````````````````````(T"
M```2`````````````````````````"`````@````````````````````````
M`+T````2`````````````````````````!0#```2````````````````````
M`````$D!```2`````````````````````````-("```2````````````````
M`````````#H"```2`````````````````````````/P!```2````````````
M`````````````*\"```2`````````````````````````%$````2````````
M`````````````````*("```2`````````````````````````.\"```2````
M`````````````````````#D#```2`````````````````````````(<!```2
M````0!M``````````````````,T#```2``T`0%9```````!P`````````)L#
M```2``X`Z%=``````````````````/(#```2``T`8$=```````#E"@``````
M`&H#```2``T``!]````````.`@```````*$#```2``T`$$%````````%````
M`````%8$```2``T`($%```````"^`0```````(,$```2``T`L%9````````Z
M`````````%`$```2``L`D!I``````````````````)\$```2``T`4%)`````
M``#G`P```````(`#```0`/'_!,Y@`````````````````-D#```2``T`X$)`
M```````E``````````P$```1``\`^%=````````$`````````,`!```1`!D`
M0,Y@```````3`````````(P#```0`/'_P-Y@`````````````````$X$```2
M``T`T#]````````J`````````&,$```2``T`0$9````````7`0```````'4$
M```2``T`P$5```````!(`````````/\#```0`!@`(')@````````````````
M`&@````2````(!Y``````````````````.8#```2``T`$$-```````#:````
M`````&\#```1`!D`,,Y@```````(`````````'D#```0`/'_!,Y@````````
M`````````'`#```A`!D`,,Y@```````(`````````/T"```1`!D`6,Y@````
M```(`````````)$#```2``T`H%=````````"`````````!@!```2````<!U`
M`````````````````#$$```2``T`$%=```````")``````````4$```2``T`
M$"%```````````````````$$```@`!@`(')@`````````````````/<````1
M`!D`(,Y@```````$`````````'$#```A`!D`,,Y@```````(`````````+(#
M```2``T`$$9````````D`````````!L$```2``T`4$!```````"V````````
M`,P````1`!D`*,Y@```````!`````````$$$```2``T`\$-```````#+`0``
M``````!L:6)P97)L+G-O+C4N,30`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES
M=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?
M<V%V95]D97-T<G5C=&]R7W@`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?
M<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L
M7VYE=U-6<'8`4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E
M90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P
M=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]D;W5N=VEN9`!097)L
M7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,
M;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO
M8P!03%]M96UO<GE?=W)A<`!L:6)P=&AR96%D+G-O+C``;W!E;C8T`')E860`
M7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`
M8VQO<V4`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M
M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M
M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US
M970`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P
M>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?
M;&]C`'-T9&5R<@!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H
M:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E
M<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?961A=&$`
M7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?
M97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P
M87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S
M=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L
M:6)C7V-S=5]I;FET`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O
M9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L
M<U]005)?0TQ%05)35$%#2P!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?
M,BXR+C4`1TQ)0D-?,BXS`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#
M7S(N-``````"``,``@`"``(``@````(``@`"`````@````(``@`$``(``@``
M`````@```````P`"````!0`"`````@`#``(``@`"````!@`````````#``(`
M```````````&```````"``,``@`"`````@`"```````"`````@`"``,`!@``
M``(`!P`&`````0`!``$``0`!``$``0`!``$``0`!``$````!``$``0`!``$`
M```!``(``0`"``(``0````$``0`!`````@`!``$````!`````0`!`,\!```0
M````(````'4::0D```,`M00````````!``4`'@(``!``````````$VEI#0``
M!P#!!```$````'09:0D```8`RP0``!````!R&6D)```%`-<$```0````%&EI
M#0``!`#C!```$````'4::0D```(`M00```````#@;V````````8````E````
M```````````@SF````````4```!B```````````````HSF````````4```!F
M```````````````PSF````````4```!9``````````````!`SF````````4`
M``!1``````````````!8SF````````4```!<````````````````<&``````
M``<````!```````````````(<&````````<````"```````````````0<&``
M``````<````#```````````````8<&````````<````$```````````````@
M<&````````<````%```````````````H<&````````<````&````````````
M```P<&````````<````'```````````````X<&````````<````(````````
M``````!`<&````````<```!$``````````````!(<&````````<````)````
M``````````!0<&````````<````*``````````````!8<&````````<````+
M``````````````!@<&````````<````,``````````````!H<&````````<`
M```-``````````````!P<&````````<````.``````````````!X<&``````
M``<````/``````````````"`<&````````<````0``````````````"(<&``
M``````<````1``````````````"0<&````````<````2``````````````"8
M<&````````<````3``````````````"@<&````````<````4````````````
M``"H<&````````<````5``````````````"P<&````````<````6````````
M``````"X<&````````<````7``````````````#`<&````````<````8````
M``````````#(<&````````<````9``````````````#0<&````````<````:
M``````````````#8<&````````<````;``````````````#@<&````````<`
M```<``````````````#H<&````````<````=``````````````#P<&``````
M``<````>``````````````#X<&````````<````?````````````````<6``
M``````<````@```````````````(<6````````<````A```````````````0
M<6````````<````B```````````````8<6````````<````C````````````
M```@<6````````<````D```````````````H<6````````<````F````````
M```````P<6````````<````G```````````````X<6````````<````H````
M``````````!`<6````````<````I``````````````!(<6````````<````J
M``````````````!0<6````````<````K``````````````!8<6````````<`
M``!>``````````````!@<6````````<````L``````````````!H<6``````
M``<````M``````````````!P<6````````<````N``````````````!X<6``
M``````<````O``````````````"`<6````````<````P``````````````"(
M<6````````<````Q``````````````"0<6````````<````R````````````
M``"8<6````````<````S``````````````"@<6````````<````T````````
M``````"H<6````````<````U``````````````"P<6````````<```!7````
M``````````"X<6````````<````V``````````````#`<6````````<````W
M``````````````#(<6````````<````Y``````````````#0<6````````<`
M```Z``````````````#8<6````````<````[``````````````#@<6``````
M``<````\``````````````#H<6````````<````]``````````````#P<6``
M``````<````^``````````````#X<6````````<````_````````````````
M<F````````<```!````````````````(<F````````<```!!````````````
M```0<F````````<```!"```````````````8<F````````<```!#````````
M``````!(@^P(Z*,&``#H,@<``.@-/0``2(/$",,``````````/\U.E4@`/\E
M/%4@``\?0`#_)3I5(`!H`````.G@_____R4R52``:`$```#IT/____\E*E4@
M`&@"````Z<#_____)2)5(`!H`P```.FP_____R4:52``:`0```#IH/____\E
M$E4@`&@%````Z9#_____)0I5(`!H!@```.F`_____R4"52``:`<```#I</__
M__\E^E0@`&@(````Z6#_____)?)4(`!H"0```.E0_____R7J5"``:`H```#I
M0/____\EXE0@`&@+````Z3#_____)=I4(`!H#````.D@_____R725"``:`T`
M``#I$/____\ERE0@`&@.````Z0#_____)<)4(`!H#P```.GP_O___R6Z5"``
M:!````#IX/[___\ELE0@`&@1````Z=#^____):I4(`!H$@```.G`_O___R6B
M5"``:!,```#IL/[___\EFE0@`&@4````Z:#^____)9)4(`!H%0```.F0_O__
M_R6*5"``:!8```#I@/[___\E@E0@`&@7````Z7#^____)7I4(`!H&````.E@
M_O___R5R5"``:!D```#I4/[___\E:E0@`&@:````Z4#^____)6)4(`!H&P``
M`.DP_O___R5:5"``:!P```#I(/[___\E4E0@`&@=````Z1#^____)4I4(`!H
M'@```.D`_O___R5"5"``:!\```#I\/W___\E.E0@`&@@````Z>#]____)3)4
M(`!H(0```.G0_?___R4J5"``:"(```#IP/W___\E(E0@`&@C````Z;#]____
M)1I4(`!H)````.F@_?___R425"``:"4```#ID/W___\E"E0@`&@F````Z8#]
M____)0)4(`!H)P```.EP_?___R7Z4R``:"@```#I8/W___\E\E,@`&@I````
MZ5#]____)>I3(`!H*@```.E`_?___R7B4R``:"L```#I,/W___\EVE,@`&@L
M````Z2#]____)=)3(`!H+0```.D0_?___R7*4R``:"X```#I`/W___\EPE,@
M`&@O````Z?#\____);I3(`!H,````.G@_/___R6R4R``:#$```#IT/S___\E
MJE,@`&@R````Z<#\____):)3(`!H,P```.FP_/___R6:4R``:#0```#IH/S_
M__\EDE,@`&@U````Z9#\____)8I3(`!H-@```.F`_/___R6"4R``:#<```#I
M</S___\E>E,@`&@X````Z6#\____)7)3(`!H.0```.E0_/___R5J4R``:#H`
M``#I0/S___\E8E,@`&@[````Z3#\____)5I3(`!H/````.D@_/___R524R``
M:#T```#I$/S___\E2E,@`&@^````Z0#\____)4)3(`!H/P```.GP^____R4Z
M4R``:$````#IX/O___\E,E,@`&A!````Z=#[____)2I3(`!H0@```.G`^___
M_R4B4R``:$,```#IL/O__U-(@^P@B7PD'$B)="002(U\)!Q(B50D"$B-="00
M2(U4)`CHZ?W__[IP'4``OR`>0`!(B=;HMS<``(`]Z*X@``!U+^CI_/__2(7`
M2(D%9[\@``^$G`$``$B)Q^@1_/__BSV[KB``Z,;]___&@,P$````BSVIKB``
MZ+3]__^`B#L%```"BSV7KB``Z*+]__^+?"0<@(@[!0```8/'!4AC_TB%_P^(
M$P$``/)(#RK'\@]8!8L[``!F#RX%BSL```^'.@$``$C!YP/HQ/S__TB+?"00
M2(D%R+X@`,<%QKX@``0```!(BQ=(QT`(X5E``$C'0!!@<F``2,=`&.190`!(
MB1"+5"0<@_H!?BJ-2OY,C03-"````#')9BX/'X0``````$B+=`\(2(ET""!(
M@\$(3#G!=>V-2@1(BSU[OB``@\(#13'`O@!`0`!(8\E(QT3(^`````!(B<'H
M5/W__X7`B<-T-DB+/4^^(`#H@OO__S'`OZ580`#H%A@``$B%P'0I2(L],KX@
M`.@%^___Z/#\__](@\0@B=A;PTB+/1F^(`#HS/W__XG#Z[I(BST!OB``2(7_
M="3HAS4``.O$2(GX2(GZ2-'H@^(!2`G0\D@/*L#R#UC`Z=7^__^_6EA``.BN
M%P``2(7`2(G'2(D%P;T@`'2.Z\&_`0```.B3_?__OD#.8`"_55A``#'`Z$+\
M__^0D#'M28G17DB)XDB#Y/!05$G'P*!70`!(Q\$05T``2,?'`!]``.B'^___
M])"02(/L"$B+!9E.(`!(A<!T`O_02(/$",.0D)"0D)"0D)"0D)"054B)Y5-(
M@^P(@#WPK"```'5+NR!N8`!(BP7JK"``2('K&&Y@`$C!^P-(@^L!2#G8<R1F
M#Q]$``!(@\`!2(D%Q:P@`/\4Q1AN8`!(BP6WK"``2#G8<N+&!:.L(``!2(/$
M"%M=PV9F9BX/'X0``````$B#/5!,(```54B)Y702N`````!(A<!T"%V_*&Y@
M`/_@7<.0D)"0D)"0D)"0D)"0D$%73(U'.#')059!54%455-(@>P(`@``9@\?
MA```````28L4"$B)T$B)UDC!X`A(P>88@^;_)0``_P!("?!(B=9(P>X(@>8`
M_P``2`GP2(G62,'N&('F_P```$@)\$B)UDC![B!(B41,B$B)\$C!YAA(P>`(
M@^;_)0``_P!("?!(B=9(P>HX2,'N*('F`/\``$@)\$@)T$B)1$R02(/!"$B#
M^4`/A7?___](C50DB$B-M"3P`0``2(/":&8/'T0``$B+0MA(,P)(,T*H2#-"
MF$B)P4@!P$C!Z1]("<&#X?](B4H82(/""$@Y\G743(L'2(M?($R+3PA,BU<0
M3(M?&$B)VDR)P$@#5"2(3(G!2,'H&TC!X05,B=Y(`W0DD$@)R$R)P8/@_TCW
MT4B-K`*9>8):3(G(3(G22/?03"'*3"'13"'82`G03(G*`<5,B<A(P>(>2,'H
M`DF)[4@)T(/@_TB)PDPAPD@)RDB)Z4R-I!:9>8):2(GJ2,'A!4C!ZAM,B=9(
M`W0DF$@)RDR)P4$!U$R)PDC!Z0)(P>(>2`G12(GJ@^'_2/?222'-2"'"3`GJ
M38GE2(VT%IEY@EI,B>))P>4%2,'J&TP)ZDV)Y0'62(GJ2,'J`DC!Y1Y(`T0D
MH$@)ZDR)Y8/B_TCWU4DAU4@AS4@#3"2H3`GM28GU2(VL*)EY@EI(B?!)P>4%
M2,'H&TP)Z$F)]0'%3(G@2<'D'DC!Z`),">!)B?2#X/])]]1)(<5)(=1(`U0D
ML$T)[$F)[4Z-I"&9>8):2(GI2<'E!4C!Z1M,">E)B>U!`<Q(B?%(P>8>2,'I
M`D@)\4B)[H/A_TCWUDDAS4@AQDP)[DV)Y4B-M#*9>8):3(GB2,'J&TG!Y05(
M`T0DN$P)ZDV)Y0'62(GJ2,'E'DC!Z@)(">I,B>6#XO](]]5)(=5((<U(`TPD
MP$P)[4F)]4B-K"B9>8):2(GP2<'E!4C!Z!M,">A)B?4!Q4R)X$G!Y!Y(P>@"
M3`G@28GT@^#_2??422'%22'42`-4),A-">Q)B>U.C:0AF7F"6DB)Z4G!Y05(
MP>D;3`GI28GM00',2(GQ2,'F'DC!Z0)("?%(B>Z#X?](]]9((<9)(<U(`T0D
MT$P)[DV)Y4B-M#*9>8):3(GB2<'E!4C!ZAM,">I-B>4!UDB)ZDC!Y1Y(P>H"
M2`GJ3(GE@^+_2/?522'52"'-2`-,)-A,">U)B?5(C:PHF7F"6DB)\$G!Y05(
MP>@;3`GH28GU`<5,B>!)P>0>2,'H`DP)X$F)](/@_TGWU$DAQ4DAU$T)[$F)
M[4Z-I"&9>8):2(GI2<'E!4C!Z1M,">E)B>U!`<Q(B?%(P>8>2,'I`D@)\4B)
M[H/A_T@#5"3@2/?622'-2"'&2`-$).A,">Y-B>5)P>4%2(VT,IEY@EI,B>)(
MP>H;3`GJ38GE`=9(B>I(P>4>2,'J`D@)ZDR)Y8/B_TCWU4DAU4@AS4@#3"3P
M3`GM28GU2(VL*)EY@EI(B?!)P>4%2,'H&TP)Z$F)]0'%3(G@2<'D'DC!Z`),
M">!)B?2#X/])]]1)(<5)(=1-">Q)B>U.C:0AF7F"6DB)Z4G!Y05(P>D;3`GI
M28GM00',2(GQ2,'I`DC!YAY(`U0D^$@)\4B)[H/A_TCWUDDAS4@AQD@#!"1,
M">Y-B>5(C;0RF7F"6DR)XDG!Y05(P>H;3`GJ38GE`=9(B>I(P>4>2,'J`D@)
MZDR)Y8/B_TCWU4DAU4@AS4@#3"0(3`GM28GU2(VL*)EY@EI(B?!)P>4%2,'H
M&TP)Z$F)]0'%3(G@2<'D'DC!Z`),">!)B?2#X/])]]1)(<5)(=1-">Q)B>U.
MC:0AF7F"6DB)Z4C!Z1M)P>4%2`-4)!!,">E)B>U!`<Q(B?%(P>8>2,'I`D@)
M\4B)[H/A_TCWUDDAS4@AQD@#1"083`GN38GE2(VT,IEY@EI,B>))P>4%2,'J
M&TP)ZDV)Y0'62(GJ2,'E'DC!Z@)(">I,B>6#XO](]]5)(=5((<U(`TPD($P)
M[4F)]4B-K"B9>8):2(GP2<'E!4C!Z!M,">A)B?4!Q4R)X$G!Y!Y(P>@"3`G@
M28GT@^#_2??422'422'%2`-4)"A-">Q.C:PAF7F"6DB)Z4F)[$G!Y`5(P>D;
M3`GA00'-2(GQ2,'F'DC!Z0)("?&#X?](B<Y(,<9(`T0D,$@Q[DR-I#*AZ]EN
M3(GJ3(GN2,'F!4C!ZAM("?)!`=1(B>I(P>4>2,'J`D@)ZH/B_TB)UD@QSD@#
M3"0X3#'N2(VL,*'KV6Y,B>!,B>9(P>8%2,'H&T@)\`'%3(GH2<'E'DC!Z`),
M">A)B>V#X/](B<9(,=9)P>4%2`-4)$!,,>9(C;0QH>O9;DB)Z4C!Z1M,">D!
MSDR)X4G!Y!Y(P>D"28GU3`GA2<'E!8/A_TF)S$DQQ$@#1"1(23'L3HVD(J'K
MV6Y(B?)(P>H;3`GJ00'42(GJ2,'E'DC!Z@)-B>5(">I)P>4%@^+_2(G52#'-
M2`-,)%!(,?5(C:PHH>O9;DR)X$C!Z!M,">@!Q4B)\$C!YAY(P>@"28GM2`GP
M@^#_2(G&2#'62<'E!4@#5"183#'F2(VT,:'KV6Y(B>E(P>D;3`GI`<Y,B>%)
MP>0>2,'I`DF)]4P)X4G!Y06#X?])B<Q),<1(`T0D8$DQ[$Z-I"*AZ]EN2(GR
M2,'J&TP)ZD$!U$B)ZDC!Y1Y(P>H"38GE2`GJ2<'E!8/B_TB)U4@QS4@#3"1H
M2#'U2(VL**'KV6Y,B>!(P>@;3`GH`<5(B?!(P>8>2,'H`DF)[4@)\(/@_TB)
MQD@QUDG!Y05(`U0D<$PQYDB-M#&AZ]EN2(GI2,'I&TP)Z0'.3(GA2<'D'DC!
MZ0))B?5,">%)P>4%@^'_28G,23'$2`-$)'A),>Q.C:0BH>O9;DB)\DC!ZAM,
M">I!`=1(B>I(P>4>2,'J`DV)Y4@)ZDG!Y06#XO](B=5(,<U(`XPD@````$@Q
M]4B-K"BAZ]EN3(G@2,'H&TP)Z`'%2(GP2,'F'DC!Z`))B>U("?"#X/](B<9(
M,=9)P>4%2`.4)(@```!,,>9(C;0QH>O9;DB)Z4C!Z1M,">D!SDR)X4G!Y!Y(
MP>D"28GU3`GA2<'E!8/A_TF)S$DQQ$@#A"20````23'L3HVD(J'KV6Y(B?)(
MP>H;3`GJ00'42(GJ2,'E'DC!Z@)-B>5(">I)P>4%@^+_2(G52#'-2`.,))@`
M``!(,?5(C:PHH>O9;DR)X$C!Z!M,">@!Q4B)\$C!YAY(P>@"28GM2`GP@^#_
M2(G&2#'62<'E!4@#E"2@````3#'F2(VT,:'KV6Y(B>E(P>D;3`GI`<Y,B>%)
MP>0>2,'I`DF)]4P)X4G!Y06#X?])B<Q),<1(`X0DJ````$DQ[$Z-I"*AZ]EN
M2(GR2,'J&TP)ZD$!U$B)ZDC!Y1Y(P>H"38GE2`GJ2<'E!8/B_TB)U4@QS4@#
MC"2P````2#'U2(VL**'KV6Y,B>!(P>@;3`GH`<5(B?!(P>8>2,'H`D@)\(/@
M_TB)QD@QUD@#E"2X````3#'F3(VL,:'KV6Y(B>E(B>Y(P>8%2,'I&T@)\4R)
MYDG!Y!Y(P>X"00'-3`GF@^;_2(GQ2#'!2`.$),````!(,>E,C:0*H>O9;DR)
MZDR)Z4C!X05(P>H;2`G*2(GI2,'E'DC!Z0)!`=1(">F#X?](B<I(,?),,>I(
MC:P0H>O9;DR)X$R)XDC!X@5(P>@;2`G03(GJ2<'E'@'%2,'J`KC<O!N/3`GJ
M28G%3`.L),@```"#XO])B=9,`>Y)B=5)(<Y)"<U-(>5-"?5)B>Y)`?5(B>Y)
MP>8%2,'N&TP)]D$!]4R)YDG!Y!Y(P>X"3`GF28G$3`.D)-````"#YO])B?9)
M(=9,`>%)B?1)"=1)(>Q-"?1-B>Y)`<Q,B>E)P>8%2,'I&TP)\4$!S$B)Z4C!
MY1Y(P>D"2`GI2(G%2`.L)-@```"#X?])B<Y(`>I(B<U("?5,(>U)(?9,"?5-
MB>9(`=5,B>))P>8%2,'J&TP)\@'53(GJ2<'E'DC!Z@),">I)B<5,`ZPDX```
M`(/B_TF)UDDASDP![DF)U4D)S4TAY4T)]4F)[DD!]4B)[DG!Y@5(P>X;3`GV
M00'U3(GF2<'D'DC![@),">9)B<1,`Z0DZ````(/F_TF)]DDAUDP!X4F)]$D)
MU$DA[$T)]$V)[DD!S$R)Z4C!Z1M)P>8%3`GQ00',2(GI2,'E'DC!Z0)(">E(
MB<5(`ZPD\````(/A_TF)SDDA]D@!ZDB)S4@)]4PA[4P)]4V)YD@!U4R)XDG!
MY@5(P>H;3`GR`=5,B>I)P>4>2,'J`DP)ZDF)Q4P#K"3X````@^+_28G622'.
M3`'N28G520G-32'E30GU28GN20'U2(GN2<'F!4C![AM,"?9!`?5,B>9)P>0>
M2,'N`DP)YDF)Q$P#I"0``0``@^;_28GV22'63`'A28GT20G422'L30GT38GN
M20',3(GI2<'F!4C!Z1M,"?%!`<Q(B>E(P>4>2,'I`D@)Z4B)Q4@#K"0(`0``
M@^'_28G.22'V2`'J2(G-2`GU3"'M3`GU38GF2`'53(GB2<'F!4C!ZAM,"?(!
MU4R)ZDG!Y1Y(P>H"3`GJ28G%3`.L)!`!``"#XO])B=9)(<Y,`>Y)B=5)"<U-
M(>5-"?5)B>Y)`?5(B>Y)P>8%2,'N&TP)]D$!]4R)YDG!Y!Y(P>X"3`GF28G$
M3`.D)!@!``"#YO])B?9)(=9,`>%)B?1)"=1)(>Q-"?1-B>Y)`<Q,B>E)P>8%
M2,'I&TP)\4$!S$B)Z4C!Y1Y(P>D"2`GI2(G%2`.L)"`!``"#X?])B<Y(`>I(
MB<U)(?9("?5,(>U,"?5-B>9(`=5,B>))P>8%2,'J&TP)\@'53(GJ2<'E'DC!
MZ@),">I)B<5,`ZPD*`$``(/B_TF)UDDASDP![DF)U4D)S4TAY4T)]4F)[DD!
M]4B)[DG!Y@5(P>X;3`GV00'U3(GF2<'D'DC![@),">9)B<1,`Z0D,`$``(/F
M_TF)]DP!X4F)]$D)U$DA[$DAUDT)]$V)[DD!S$R)Z4G!Y@5(P>D;3`GQ00',
M2(GI2,'E'DC!Z0)(">E(B<5(`ZPD.`$``(/A_TF)SDDA]D@!ZDB)S4@)]4PA
M[4P)]4V)YD@!U4R)XDG!Y@5(P>H;3`GR`=5,B>I)P>4>2,'J`DP)ZDF)Q4P#
MK"1``0``@^+_28G622'.3`'N28G520G-32'E30GU28GN20'U2(GN2,'N&TG!
MY@5,"?9!`?5,B>9)P>0>2,'N`DP)YDF)Q$P#I"1(`0``@^;_28GV22'63`'A
M28GT20G422'L30GT38GN20',3(GI2<'F!4C!Z1M,"?%!`<Q(B>E(P>4>2,'I
M`D@)Z4B)Q4@#K"10`0``@^'_28G.22'V2`'J2(G-2`GU3"'M3`GU38GF2`'5
M3(GB2<'F!4C!ZAM,"?(!U4R)ZDG!Y1Y(P>H"3`GJ28G%3`.L)%@!``"#XO](
M`X0D8`$``$F)UDDASDP![DF)U4D)S4@!P4TAY4T)]4F)[DD!]4B)[DG!Y@5(
MP>X;3`GV00'U3(GF2<'D'DC![@),">:#YO](B?!)B?1("=!)(=1((>A,">!)
MB>Q(P>4>3(TT`4R)Z$R)Z4C!X05(P>@;2<'L`D@)R$D)[$$!QKC6P6+*08/D
M_TB)P4@#C"1H`0``3(GU2,'E!4@!RDR)X4@Q\4PQZ4@!T4R)\DC!ZAM(">I,
MB>U)P>4>1(T\"DB)PD@#E"1P`0``2,'M`DP)[4R)^8/E_TC!X05(`=9(B>I,
M,>),,?),C2P63(GZ2,'J&T@)RDR)\4G!YAY!`=5(B<)(`Y0D>`$``$C!Z0),
MB>Y,"?%(P>8%@^'_20'42(G*2#'J3#'Z20'43(GJ2,'J&T@)\DB)QD$!U$@#
MM"2``0``3(GZ2,'J`DG!YQY-B>9,"?I)P>8%@^+_2`'U2(G62#'.3#'N2`'U
M3(GF2,'N&TP)]@'U3(GN2<'E'DC![@))B>Y,">Y)B<5,`ZPDB`$``(/F_TG!
MY@5,`>E)B?5),=5-,>5)`<U(B>E(P>D;3`GQ00'-3(GA2<'D'DC!Z0)-B>Y,
M">%)B<1,`Z0DD`$``(/A_TP!XDF)S$DQ]$G!Y@5),>Q)`=1,B>I(P>H;3`GR
M00'42(GJ2,'E'DC!Z@)-B>9(">I(B<5(`ZPDF`$``(/B_TG!Y@5(`>Y(B=5(
M,<U,,>U(`?5,B>9(P>X;3`GV`?5,B>Y)P>4>2,'N`DF)[DP)[DF)Q4P#K"2@
M`0``@^;_2<'F!4P!Z4F)]4DQU4TQY4D!S4B)Z4C!Z1M,"?%!`<U,B>%(P>D"
M2<'D'DV)[DP)X4F)Q$P#I"2H`0``@^'_2<'F!4P!XDF)S$DQ]$DQ[$D!U$R)
MZDC!ZAM,"?)!`=1(B>I(P>4>2,'J`DV)YD@)ZDB)Q4@#K"2P`0``@^+_2<'F
M!4@![DB)U4@QS4PQ[4@!]4R)YDC![AM,"?8!]4R)[DG!Y1Y(P>X"28GN3`GN
M28G%3`.L)+@!``"#YO],`>E)B?5),=5-,>5)P>8%20'-2(GI2,'I&TP)\4$!
MS4R)X4G!Y!Y(P>D"38GN3`GA28G$3`.D),`!``"#X?])P>8%3`'B28G,23'T
M23'L20'43(GJ2,'J&TP)\D$!U$B)ZDC!Y1Y(P>H"38GF2`GJ2(G%2`.L),@!
M``"#XO])P>8%2`'N2(G52#'-3#'M2`'U3(GF2,'N&TP)]@'U3(GN2,'N`DG!
MY1Y)B>Y,">Y)B<5,`ZPDT`$``(/F_TG!Y@5,`>E)B?5),=5-,>5)`<U(B>E(
MP>D;3`GQ00'-3(GA2<'D'DC!Z0)-B>Y,">%)B<1,`Z0DV`$``(/A_TG!Y@5,
M`>))B<Q),?1),>Q)`=1,B>I(P>H;3`GR00'42(GJ2,'E'DC!Z@)-B>9(">I(
MB<5(`ZPDX`$``(/B_T@![DB)U4@QS4PQ[4@!]4R)YDG!Y@5(P>X;3`GV`?5,
MB>Y)P>4>2,'N`DF)[DP)[DF)Q4P#K"3H`0``@^;_2<'F!4P!Z4F)]4DQU4TQ
MY4D!S4B)Z4C!Z1M,"?%!`<U,B>%)P>0>2,'I`DV)[DP)X4F)Q$P#I"3P`0``
M@^'_2<'F!4P!XDF)S$DQ]$DQ[$D!U$R)ZDC!ZAM,"?)!`=1(B>I(P>4>2,'J
M`DV)YD@)ZDB)Q4@#K"3X`0``@^+_2<'F!4@#A"0``@``2`'N2(G52#'-2`'!
M3#'M2`'U3(GF2,'N&TP)]D2--"Y,B>Y)P>4>2,'N`DR)Y4P)[DV)Y4C![0*#
MYO])P>4>10'Q2(GP3`GM1`'>2#'000'J`=I,,>!-B?1(`<%,B?!)P>0%2,'H
M&TP)X`'(00'`3(D'3(E/"$R)5Q!(B7<82(E7($B!Q`@"``!;74%<05U!7D%?
MPV8/'T0``$%728GW059!54F)_4%455-(@^P(2(7_=&U,BS50EB``387V=&$/
MM@<\/71TA,!T<$F)_$F#Q`%!#[8$)#P]=`2$P'7O12GL28L>,<!(A=MT-TUC
MY$R)]68/'X0``````$R)XDR)[DB)W^C"XO__A<!U!T*`/",]="](@\4(2(M=
M`$B%VW7:,<!(@\0(6UU!7$%=05Y!7\-F#Q^$``````!%,>3KH@\?`$PI]4J-
M1",!2,']`T&)+TB#Q`A;74%<05U!7D%?PV8N#Q^$``````!(@^P8,<!(C70D
M#.@@____2(/$&,-F9BX/'X0``````%-(B?M(@^P0#Q^$``````!(C70D##'`
M2(G?Z/'^__](A<!T+DAC1"0,2(L54)4@`$B-!,)(BU`(2(722(D0=-!(@\`(
M2(M0"$B%TDB)$'7PZ[Y(@\006\,/'X0``````%532(/L"(L]!)4@`.@/Y/__
MBSWYE"``2(N`8`(``$B+:`CH^>/__XL]XY0@``^VF,0$``#HY^/__TB+0`B#
MXW\/MT`@P>`'"=AFB44"BSV]E"``Z,CC__^+/;*4(`!(BX!@`@``2(M8".BR
MX___,=*^VUE``$B)Q^B3X___BSV-E"``2(E#*.B4X___BSU^E"``2(N`8`(`
M`$B+6`CH?N/__TB+@(`&``"+/6&4(`!(B4,PZ&CC__^+/5*4(`!(BX!@`@``
M2(M8".A2X___,=)(@[CX"0```'09BSTPE"``Z#OC__](BX#X"0``2(N0J```
M`(L]%Y0@`$B)4SCH'N/__TB+@&`"``"+/0&4(`!(BT`(2,=`0`````#H`./_
M_TB+@&`"``"+/>.3(`!(BT`(2,=`(`````#HXN+__XL]S),@`$B+@&`"``!(
MBU@(Z,SB__](BX!P`@``2(E#2$B#Q`A;7<-F+@\?A```````2(E<)-A(B6PD
MX$B)^TR)9"3H3(EL)/!,B70D^$B![+@```!(A?]T!8`_`'4S2(N<))````!(
MBZPDF````$R+I"2@````3(NL)*@```!,B[0DL````$B!Q+@```###Q\`Z'O@
M__](A<!(B<5TP`\?`$B)[^@(X___2(7`28G$#X2D````08!\)!,N#X2P````
M38UL)!-(B=_HD^#__TR)[TF)QNB(X/__18UT!@))8_[H"^+__TV)Z4F)Q$B)
MQTF)V+G\5T``2,?"_____[X!````,<#HE^/__[\!````2(GB3(GFZ.??__^#
M^/],B>=T$(M$)!@E`/```#T`0```=&_H6M___TR)Y^@RW___2(GOZ&KB__](
MA<!)B<0/A6+___]F#Q]$``!(B>_HH.#__TB)W^CHW___Z?#^__\/'P!!@'PD
M%``/A"3___]!@'PD%"X/A3C___]!@'PD%0`/A`S____I)____P\?@`````#H
MB_[__^N/9@\?A```````2(E<)/!(B6PD^$B)^TB#[!B+/0F2(``Q[>@2X?__
M2(V0F````$B)WK\!````Z$[B__^%P'0:B>A(BUPD"$B+;"002(/$&,-F#Q^$
M``````"+/<J1(`#HU>#__XN`L````"4`\```/0!```!T'8L]K9$@`.BXX/__
MBX"P````)0#P```]`*```'6LO@(```!(B=\Q[>B7X?__A<!`#Y3%ZY5F9F9F
M9F8N#Q^$``````!!5S'`059!54%454B)_5-(B?-(@^PH@#X]#Y3`2`'#2(G?
MZ-G>__](C70D'$&)Q4B)[S'`Z-?Z__](A<!)B<0/A`L!``!(B<?HL][__T2)
MZ3'22#G(#X/-````1(MD)!P/MD4`/#T/A*0!``"$P`^$G`$``$B)Z.L+#Q^`
M`````(32=`Q(@\`!#[80@/H]=?`IZ$B+#>>0(`!!C7P%`DZ-).'HZ=___TB%
MP$F)!"0/A&,!``"+5"0<2(L%P9`@`$B+!-`/ME4`A-*($'0J@/H]="5(@\4!
MZPT/'X0``````(#Z/702#[95`$B#P`%(@\4!A-*($'7IQ@`],=(/'T``#[8,
M$XA,$`%(@\(!A,EU\#'`2(/$*%M=05Q!74%>05_##Q^```````^V!!-!B`04
M2(/"`83`=-@/M@0308@$%$B#P@&$P'7@Z\9F#Q]$``!,BSTID"``13'DOA``
M``!)@S\`="5,B?@/'X0``````$B#P`A!@\0!2(,X`'7R08UT)`)(8_9(P>8#
MBSU`D"``A?]T-$R)_^B$W___2(7`28G&2(D%UX\@`'1L26/,2<=$S@@`````
M1(ED)!SIG_[__P\?@`````!(B??'!?N/(``!````Z+;>__](A<!)B<9T-4EC
MS$R)_DB)QTB-%,T`````2(E,)`CH0]___TR)-7R/(`!(BTPD".NC#Q]$```Q
MP.E[_O__N/_____I\?[__V9F9F9F9BX/'X0``````$B)7"3H3(ED)/A(B?M(
MB6PD\$B!["@0``!)B?2Z_P\``$B)YK\"6$``9$B+!"4H````2(F$)`@0```Q
MP.COV___A<`/CG\```"-4/](8^J`/"P`=&M(8^A(B>J^+P```$B)Y^A8W?__
M2(7`=%N+/<V.(`#HV-W__TB)Z4B)XDB)WDB)Q^CGWO__2(N$)`@0``!D2#,$
M)2@```!U1TB+G"00$```2(NL)!@0``!,BZ0D(!```$B!Q"@0``###Q]``(72
M=90/'T``BSURCB``Z'W=__],B>)(B=Y(B<?H/]S__^NFZ/C;__\/'X0`````
M`$B#[`B+/4:.(`#H4=W__[D16$``ND`;0`"^&UA``$B)QTB#Q`CI9MW__V8/
M'T0``$B#[`B+/1:.(`#H(=W__TB)Q^BY____BST#CB``Z`[=__]!N-M90`!%
M,<FZ4%)``$R)P;XW6$``2(G'2(/$".E\W?__9F9F+@\?A```````55,QVTB!
M["@@``!D2(L$)2@```!(B80D&"```#'`Z+W:__]!N0U80`!!B<"Y3%A``#'`
MN@$0``"^`0```$B)Y^A;WO__A<!X2$B-M"00$```N@`0``!(B>?H8MK__X7`
MB<5X+8U]`4AC_^B!W/__2(7`2(G#=!I(8^U(C;0D$!```$B)QTB)ZNCSV___
MQ@0K`$B+E"08(```9$@S%"4H````2(G8=0I(@<0H(```6UW#Z+K:__]F+@\?
MA```````Z3O___]F9BX/'X0``````$%528GU05152(G]OUI80`!32('L*!``
M`&1(BP0E*````$B)A"08$```,<#H0/?__[XO````2(GO2(G#Z(#:__](A<!T
M-TB)[K]C6$``,<#H//O__TB+E"08$```9$@S%"4H````2(GH#X5+`0``2('$
M*!```%M=05Q!7<-(B>_H#-K__TR)[[YP6$``08G$Z(S<__])B<5F#Q^$````
M``!-A>UTH$&`?0``N%A80`!,#T3H2(7;=!-,B>Y(B=_H_=K__X7`#X2F````
M3(GOZ+W9__](8]!!@'P5_R]U&4F-5!7_#Q]$``#&`@!(@^H!@^@!@#HO=/%!
MC40$`3W_#P``#X\^____2(U\)!!!N7)80`!-B>BYC%E``+H`$```O@$````Q
MP$B)+"3HH=S__XL]RXL@`.C6VO__2(UT)!!(C9"8````OP$```#HX-C__X7`
M=1V+/::+(`#HL=K__XN`L````"4`\```/0"```!T%+YP6$``,?_HH]O__TF)
MQ>D;____2(U\)!"^`0```.A\V___A<!UV4B-="00OV-80`#HZ?G__TB-?"00
MZ*_9__](B<7IF_[__^CBV/__9I`/M@](B?B$R7092(U7`6:0@/DO2`]$PDB#
MP@$/MDK_A,EU[?/#9F8N#Q^$``````!(A?]32(G[=">`/P!T(NB-V/__2(U4
M`_](.=-R#.L_D$B#Z@%(.=IT?X`Z+W3RZR6_`@```.CVV?__2(7`=`5FQP`N
M`%O#9BX/'X0``````(`Z+W0)2(/J`4@YTW+R2#G:=$4/'T0``$B#Z@%(.=-S
M!8`Z+W3R2"G:,<!(C4H"2('Y`!```'>\2(G>2(/"`;D`$```OZ#.8`#H\MG_
M_[B@SF``6\,/'P"`.B]T"UN_<EA``.FXV/__OP(```#H;MG__TB)PC'`2(72
M#X1T____9L<"+@!(B=!;PV8/'T0``$B#[#B_=%A``&1(BP0E*````$B)1"0H
M,<!(BP78%0``2(D$)$B+!=45``!(B40D"$B+!=$5``!(B40D$$B+!<T5``!(
MB40D&`^W!<D5``!FB40D(#'`Z&7T__\QP+]]6$``Z%GT__\QP+^%6$``Z$WT
M__\QP+^.6$``Z$'T__\QP+^56$``Z#7T__\QP+^E6$``Z"GT__\QP+]:6$``
MZ!WT__\QP+^Q6$``Z!'T__\QP+^[6$``Z`7T__\QP+_%6$``Z/GS__\QP+]C
M6$``Z.WS__\QP+_/6$``Z.'S__\QP+_86$``Z-7S__\QP+_C6$``Z*GS__](
MA<!T#TB)QK^[6$``,<#HM??__S'`O_180`#HB?/__TB%P'0/2(G&OP990``Q
MP.B5]___,<"_$5E``.AI\___2(7`=#Q(B<:_6EA``#'`Z'7W__\QP+X]64``
MOY580`#H9/?__TB+1"0H9$@S!"4H````=5I(@\0XPP\?@``````QP+\A64``
MZ!SS__](A<!T%TB)QK^Q6$``,<#H*/?__^NQ9@\?1```2(UT)!&_,EE``+D*
M````\Z9UF$B-="0;O[%80``QP.C\]O__ZX7H!=;__P\?1```2(/L"(L%=BP@
M`(/X_W0)2(/$",,/'T``,<"_L5A``.BL\O__2(G",<!(A=)T#P^V$H32=`@Q
MP(#Z,`^5P(D%/2P@`$B#Q`C##Q^$``````!(@^P(Z+?5__^)Q^A@U?__2(7`
M=`M(BP!(@\0(PP\?`#'`Z_1F9F8N#Q^$``````!!5D%5051)B?Q54[M)64``
M2(/L4$C'1"0025E``$C'1"08/UE``$B-;"082,=$)"!,64``2,=$)"A"64``
M2,=$)#!'64``2,=$)#A964``2,=$)$``````ZR!F#Q]$``!(B<?H*-C__TB%
MP'132(/%"$B+7?A(A=MT,3'`2(G?Z,SQ__](A<!)B<9,B>9T!8`X`'7,2(G?
M,<#HTO7__TB#Q0A(BUWX2(7;=<](@\106UU!7$%=05[##Q^$``````!,B>?H
MJ-3__TR)]TF)Q>B=U/__28U\!0+H(];__T&Y<%A``$F)Q4B)QTV)X+F,64``
M2,?"_____[X!````,<!,B30DZ*C7__],B>Y(B=\QP.A;]?__ZX=F#Q^$````
M``!!5T%6055!5%532(G[OUI80`!(@>R(@0``9$B+!"4H````2(F$)'B!```Q
MP$C'1"1P<%E``$C'1"1X6%A``$C'A"2``````````$C'1"1`!EE``$C'1"1(
M_UA``$C'1"10=5E``$C'1"18'%E``$C'1"1@?5E``$C'1"1H`````$C'A"20
M````9%E``$C'A"28````@5E``$C'A"2@`````````.B'\/__2(7`=`F`.``/
MA>D#```QP.CR_?__2(7`28G&#X3X`P``00^V+D"$[70IZ*C6__],B?(/'T0`
M`$B+"$@/ONWV!&D(=0/&`E](@\(!#[8J0(3M=>1,C60D2+\&64``ZQ8/'X0`
M`````$F#Q`A)BWPD^$B%_W0R,<#H"_#__TB%P$B)Q73C@#@`=-Y(B<?H9O/_
M_X7`=-)(B>_HVM/__TB%P$F)Q75=9I!(BVPD<$4Q[4B%[71.@'T``$&\`0``
M`'4FZT`/'T0``$ECQ$B+;,1P2(7M#X1'`0``08/$`8!]```/A#D!``!(B>_H
M"?/__X7`=-5(B>_H?=/__TB%P$F)Q73%3(GOZ)W2__],B?=(B<7HDM+__XVL
M!00$``!(8^U(B>_H$-3__T&Y<EA``$B)QTF)Q$V)Z+F*64``2,?"_____[X!
M````,<!,B70D"$C'!"2364``Z(S5__^^P`$``$R)Y^B/T?__@_C_='J+/:2$
M(`#HK]/__TB-D)@```!,B>:_`0```.CKU/__A<`/A),```!(BPM(BSVQA"``
M38G@NE!:0`"^`0```#'`,>WH\]3__TB+E"1X@0``9$@S%"4H````2(GH#X5I
M"```2('$B($``%M=05Q!74%>05_##Q^``````.C;T/__1(L(08/Y$0^$=/__
M_TB+"TB+/4R$(`!-B>"Z$%I``+X!````,<`Q[>B.U/__ZYD/'T``13'MZ=O^
M__^+/>J#(`#H]=+__XN`L````"4`\```/0!````/A4S___^+/<F#(`#HU-+_
M_T2+J+0```#H:-'__T$YQ0^%+/___XL]J8,@`.BTTO__BX"P````)?\!```]
MP`$```^%"____TB)[^BFTO__OT)90`!(B<4QP.CG[?__2(7`2(G'#X2_`0``
MZ,;1__](BSM(B<;H6_;__TB%P$F)Q0^$HP$``$R)[^C7T/__@_@#?C)(8]"_
MF%E``+D%````28UT%?SSIG4<@_@$#X1%!@``@^@$2)A!@'P%_R\/A#0&``!F
MD#'`Z*GZ__^%P'45,?9,B>_HN]+__X7`08G&#X5,`0``OCU90`"_L5A``#'`
MZ&_Q___HZL___T&Y<EA``(D$)$V)X+FV64``2,?"_____[X!````2(GO,<!(
MQT0D"-M90``QV^AXT___ZTQF#Q]$``#H2\___X,X$75.Z*'/__^#PP&)!"1!
MN7)80`!-B>"YQ%E``$C'PO____^^`0```$B)[S'`2,=$)!#;64``B5PD".@J
MT___OL`!``!(B>_H+<___X/X_W2H3(GGZ.#.__](B>Z_6EA``#'`Z,'P__](
MB>_H2?K__^G!_?__#Q]``$B)QTB)1"0@Z#/Z__](BT0D($B)Q^AFT/__2(G%
MZ9O]__^]`0```+]D64``ZQ5FD$ACQ8/%`4B+O,20````2(7_="8QP.A&[/__
M2(7`=.&`.`!TW$B)Q^@DT/__2(7`28G&=,SIP?O__T&^:5E``.GH^___3(LK
MZ57^__^Z`@```$C'QN[___^)Q^@1TO__2(VT)+````"Z!@```$2)]^@,T/__
M@+PDL`````!U#H"\)+$```!##X0"!0``,=(Q]D2)]^C8T?__2(V<).B```!!
MN(FKS>]!N?[<NIA!NO#ATL-(QX0DL(````$C16=,B80DN(```$R)C"3`@```
M2,>$),B```!V5#(03(F4)-"```!(QX0DV(````````!(QX0DX(````````#'
MA"0H@0````````\?`$B-M"2P````N@"```!$B??H8\___X7`08G%#XY^`0``
M2(N,)-B```!)8\6+O"0H@0``3(V\)+````"-%,%(.<I(B90DV(````^2P4C!
MZ!T/MLE(`8PDX(```$@!A"3@@```A?]T:D&_0````$B-M"2P````02G_2&/_
M13G]10]._4@!WTECQTB)PDB)1"0HZ`3/__^+A"0H@0``1`'X@_A`B80D*($`
M``^%4O___TB-O"2P@```12G]3(V\)+````!,`WPD*.C]T___#Q]$``!!@_T_
M#XZD````08U5P,'J!HG0B50D-$B)1"0X2,'@!DF-1`=`2(E$)"A,B?@/'P!(
MBQ!(C;PDL(```$B)$TB+4`A(B5,(2(M0$$B)4Q!(BU`82(E3&$B+4"!(B5,@
M2(M0*$B)4RA(BU`P2(E3,$B+4#A(@\!`2(E3.$B)1"0@Z'33__](BT0D($@[
M1"0H=:!(BT0D.$B#P`%(P>`&20''BT0D-/?8P>`&18UL!<!)8]6Y2````$R)
M_DB)W^@WSO__1(FL)"B!``#I8O[__T2)]^ABS?__2(N<)-B```!,BZPDX(``
M`$B)V$C!Z`.#X#^-2`%(8]#&A!3H@```@(/Y.`^/;`(``+HW````2&/),?8I
MPDB-O`SH@```2&/2Z.7,__],B>A(C;PDL(```$2(K"0C@0``2,'H&(B<)">!
M``"(A"0@@0``3(GH2,'H$(B$)"&!``!,B>A,C:PD,($``$C!Z`B(A"0B@0``
M2(G82,'H&(B$)"2!``!(B=A(P>@0B(0D)8$``$B)V#';2,'H"(B$)":!``#H
M6]+__TB+A"2P@```2(G"B(0D8X$``$C!ZAA!B="(E"1@@0``2(G"2,'J$(B4
M)&&!``!(B<)(BX0DN(```$C!Z@B(E"1B@0``2(G"B(0D9X$``$C!ZAB(E"1D
M@0``2(G"2,'J$(B4)&6!``!(B<)(BX0DP(```$C!Z@B(E"1F@0``2(G"B(0D
M:X$``$C!ZAB(E"1H@0``2(G"2,'J$(B4)&F!``!(B<)(BX0DR(```$C!Z@B(
ME"1J@0``2(G"B(0D;X$``$C!ZAB(E"1L@0``2(G"2,'J$(B4)&V!``!(B<)(
MBX0DT(```$C!Z@B(E"1N@0``2(G"B(0D<X$``$C!ZAB(E"1P@0``2(G"2,'J
M$(B4)'&!``!(B<)(P>H(B)0D<H$``.D/````9@\?1```1`^VA!Q@@0``28U\
M70`QP$4/ML"YL5E``$C'PO____^^`0```$B#PP'H\LW__TB#^Q1US,:$)%B!
M````2,=$)`C;64``3(DL)$&Y<EA``$V)X+FB64``2,?"_____[X!````2(GO
M,<#HL\W__^F6^O__2(M;"$B%VP^$P?G__TB)W^A9RO__2(/X`P^&K_G__TB-
M=`/\OYU90`"Y!0```/.F3`]$Z^F5^?__2&/)NC\````Q]DB-O`SH@```*<)(
M8]+H><K__TB-O"2P@```Z%S0__](C90DZ(```+D'````,<!(B=?S2*OI;?W_
M_X"\)+(```!!#X7P^O__@+PDLP```$,/A>+Z__^`O"2T````2`^%U/K__X"\
M)+4```!%#X7&^O__N@(```!(Q\;&____1(GWZ);,__](C;0DL````+HI````
M1(GWZ)'*__](C90DL````$C'1"0(VUE``$B)%"3IX/[__P\?@`````#H>\G_
M_V9F+@\?A```````055!5%532(/L"(L]P'L@`.C+RO__OY580`#&@,4$```!
M,<#H&.;__TB%P'0)@#@Q#X2*`@``,<#H8_'__XL]C7L@`.B8RO__N0L```"Z
M`0```+[564``2(G'Z$'*__](A<`/A+D```!(BT`0,=M,BV`HBP7@BR``@_@!
M#XZ5````O0@```#K-`\?A```````28MU$$B+!;6+(`!(BSPHZ.S)__^%P'5H
M@\,!BP6GBR``2(/%"(U3`3G0?EJ+/0Y[(`#H&<K__S')B=I,B>9(B<?HZLK_
M_TB%P'0U3(LH0?9%#01UJXL]Y7H@`.CPR?__3(GNN0(````QTDB)Q^C.R/__
M2(G&ZXUF#Q^$``````"+!4*+(`"-4/\YV@^$-P$``(L]J7H@`.BTR?__N00`
M``"Z`0```+[:64``2(G'Z%W)__](A<!(B<-T,TB+0!"+/7MZ(`!(BRCH@\G_
M_[K<64``2(G'2(GNZ$/(__](BT,02(L8]D,.0`^%(@$``(L]3'H@`.A7R?__
MN00```"Z`0```+[A6$``2(G'Z`#)__](A<!(B<-T.#'`OV-80`#HC.3__TB%
MP$F)Q`^$B`$``$B+0Q"+/09Z(`!(BRCH#LG__TR)XDB)QTB)[NC0Q___BSWJ
M>2``Z/7(__^+/=]Y(`#&@,4$````Z./(__^_6EA``$C'@$@'````````,<#H
M+.3__TB%P$B)!4**(``/A+0```"^P`$``$B)Q^A_QO__@_@1=!"%P'0,@_C_
M#Q\`#X6"`0``2(/$"%M=05Q!7<,/'X``````@_@!#X[`_O__NP$```!F+@\?
MA```````BSU:>2``@\,!Z&+(__],B>9(B<?H1\;__SD=R8D@`'_?Z8O^__]F
M+@\?A```````BSTJ>2``Z#7(__](B=Y(B<?HBLC__^G#_O__#Q]$``"`>`$`
M#X1S_?__9@\?1```Z6']__\/'P!(BSUQB2``Z"SR__](A<!(B05RB2``#X3*
M````2(M#$$B++5&)(`!,BR!!]D0D#01T:DF+?"002(GNZ/G(__^)Q4B+0Q!(
MBQCV0PT$='-(BU,02(L%'XD@`(GIO]!:0`!(BS`QP.B^Q___9@\?1```2(L%
M`8D@`(L]>W@@`$R+($B+0Q!(BRCH?,?__TR)YDB)[^@AZ?__Z6S^__^+/59X
M(`#H8<?__[D"````2(G',=),B>;H/\;__TB)Q^EV____BSTQ>"``Z#S'__\Q
MTKD"````2(G>2(G'Z!K&__](B<+I;/___[^H6D``Z#C'__^)P4B+!7^((`!(
MBQ6(B"``O_A:0`!(BS`QP.@9Q___9@\?A```````54B)_5-(@^P(Z,+L__\/
MMA!(B<.$TG0;2(U``0\?0`"`^B](#T382(/``0^V4/^$TG7M,<#H1N___X7`
M=!U(A>UT&(!]``!T$KZ364``2(G?Z#K(__](.=AT!TB#Q`A;7<-(@\0(2(GO
M6UWIT./__TB#[`B+/69W(`#H<<;__[[_____2(G'Z)3%__^+/4YW(`#H6<;_
M_S'2OA`Y0`!(B<=(@\0(Z=;'__^0D)"0D)!(C04Q&R``2(7`=`Q(BPTE&R``
MZ6C%__\QR>OWD)"0D$B);"383(ED).!(C2WC%B``3(TEW!8@`$R);"3H3(ET
M)/!,B7PD^$B)7"302(/L.$PIY4&)_4F)]DC!_0-)B=?H.\/__TB%[70<,=L/
M'T``3(GZ3(GV1(GO0?\4W$B#PP%(.>MUZDB+7"0(2(ML)!!,BV0D&$R+;"0@
M3(MT)"A,BWPD,$B#Q#C##Q^``````//#D)"0D)"0D)"0D)"0D)!52(GE4TB#
M[`A(BP5(%B``2(/X_W09NPAN8``/'T0``$B#ZPC_T$B+`TB#^/]U\4B#Q`A;
M7<.0D$B#[`CH;\G__TB#Q`C#```!``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`
M<&5R;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P`N`%!!4E]414U0`%!!4E]04D]'
M3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$14)5
M1P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,24)0051(`$193$1?
M3$E"4D%265]0051(`%-(3$E"7U!!5$@`55-%4@!365-414T`+W1M<`!414U0
M1$E2`%1-4`!54T523D%-10`E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S
M8V%C:&4M)7,E<P`E,#)X`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E
M<P!!4D=6`!@`<&5R;``M90`M+0``7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("```````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!E>&5C=71I;VX@;V8@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M`````````````````````````,!#`1L#._0````=````8+___Q`!``"PP___
MF`4``+#&__\X`0``<-S__X@!``!`W?__Z`$``&#=__\``@``P-W__R`"```P
MW___4`(``+#@__]X`@``8.'__Y@"``"0X___Z`(``(#D__\0`P``L.3__R@#
M````Y?__0`,``,#E__]P`P``T.7__X@#``"0Y___R`,``,#G___@`P``H.C_
M_Q`$``!PZO__,`0``,#J__]0!```\.K__W`$```0[/__N`0```#W__\(!0``
M\/K__T@%``!@^___@`4``*#[___`!0``P/O__]@%``!0_/__``8````````4
M``````````%Z4@`!>!`!&PP'")`!```D````'````$B^__]0!`````X01@X8
M2@\+=PB``#\:.RHS)"(`````3````$0```!PQ?__NA4```!"#A"/`D@.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P='#L`$`Y@5#CA!#C!!#BA"#B!"#AA"#A!"
M#@@```````!<````E````.#:___&`````$(.$(\"10X8C@-"#B"-!$4.*(P%
M00XPA@9!#CB#!T0.0`)X"@XX00XP00XH0@X@0@X80@X00@X(2@M;#CA!#C!!
M#BA"#B!"#AA"#A!"#@@4````]````%#;__\5`````$0.(%`."``<````#`$`
M`%C;__]8`````$$.$(,"1PX@`DX.$$$.""P````L`0``F-O__V8!````00X0
MA@)!#AB#`T0.(`-=`0X800X000X(`````````"0```!<`0``V-S__W<!````
M388%@P96#L`!C@*-`XP$>0H."$0+```<````A`$``##>__^A`````$V&`H,#
M1`X@=0H."$H+`$P```"D`0``P-[__R$"````0@X0CP)$#AB.`T(.((T$0@XH
MC`5!#C"&!D0..(,'1PY@`P`!"@XX00XP00XH0@X@0@X80@X00@X(2`L`````
M)````/0!``"@X/__Z`````!-C`*#!$P.L""&`P*B"@X(10L``````!0````<
M`@``:.'__RH`````1`X080X(`!0````T`@``@.'__T0`````1`X0>PX(`"P`
M``!,`@``N.'__[8`````00X0A@)!#AB#`TD.P$`"HPH.&$$.$$$."$$+````
M`!0```!\`@``2.+__P4``````````````#P```"4`@``0.+__[X!````0@X0
MC0)%#AB,`T$.((8$20XH@P5'#M`@`ET*#BA!#B!!#AA"#A!"#@A!"P`````4
M````U`(``,#C__\E```````````````L````[`(``-CC___:`````$0.$(,"
M`D$*#@A+"P)4"@X(1`M&"@X(2@MA#@@````<````'`,``(CD___+`0```$0.
M0`-L`0H."$@+`````!P````\`P``..;__T@`````1`X03PH."$4+;PX(````
M'````%P#``!HYO__)`````!$#A!8"@X(1`L```````!$````?`,``'CF__\7
M`0```$(.$(X"0@X8C0-"#B",!$0.*(8%00XP@P9)#H`!`IL*#C!!#BA!#B!"
M#AA"#A!"#@A)"P````!,````Q`,``%#G___E"@```$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T\.P(,"`V4""@XX00XP00XH0@X@0@X80@X00@X(
M2`L``#P````4!```\/'__^<#````0@X0C0)"#AB,`T$.((8$00XH@P5$#C`#
M0`(*#BA!#B!!#AA"#A!"#@A("P`````T````5`0``*#U__]P`````$$.$(8"
M1`X8@P-$#B`"5@H.&$$.$$$."$$+1`X81`X000X(`````!0```",!```V/7_
M_SH`````1`X0<0X(`"0```"D!```$+[__PX"````00X0@P)$#C`#CP$*#A!#
M#@A!"P`````4````S`0``-CU__\<```````````````D````Y`0``.#U__^)
M`````%&,!88&7PY`@P>/`HX#C00"6`X(````%`````P%``!(]O__`@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/__
M________``````````#__________P`````````````````````!````````
M``$``````````0````````#/`0````````$`````````'@(````````,````
M`````)`:0```````#0````````#H5T```````/7^_V\`````F`)````````%
M`````````&`-0```````!@````````"@`T````````H`````````[00`````
M```+`````````!@`````````%0````````````````````,`````````Z&]@
M```````"`````````&`&````````%``````````'`````````!<`````````
M,!1````````'`````````*`30```````"`````````"0``````````D`````
M````&`````````#^__]O`````"`30```````____;P`````"`````````/#_
M_V\`````3A)`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#!N8```````````````````
M`````````,8:0```````UAI```````#F&D```````/8:0```````!AM`````
M```6&T```````"8;0```````-AM```````!&&T```````%8;0```````9AM`
M``````!V&T```````(8;0```````EAM```````"F&T```````+8;0```````
MQAM```````#6&T```````.8;0```````]AM````````&'$```````!8<0```
M````)AQ````````V'$```````$8<0```````5AQ```````!F'$```````'8<
M0```````AAQ```````"6'$```````*8<0```````MAQ```````#&'$``````
M`-8<0```````YAQ```````#V'$````````8=0```````%AU````````F'4``
M`````#8=0```````1AU```````!6'4```````&8=0```````=AU```````"&
M'4```````)8=0```````IAU```````"V'4```````,8=0```````UAU`````
M``#F'4```````/8=0```````!AY````````6'D```````"8>0```````-AY`
M``````!&'D```````%8>0```````9AY```````!V'D```````(8>0```````
MEAY```````"F'D```````+8>0```````QAY```````#6'D```````.8>0```
M````]AY``````````````````````````````````````````````````/__
M__\`````````````````````````````````````(R$O=7-R+V)I;B]P97)L
M"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@
M("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K
M86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E
M(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T
M.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER
M92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@
M(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E
M;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O
M=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@
M("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@
M("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H
M87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S
M:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA
M="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@
M("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@
M:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N
M>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@
M=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U
M<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@
M("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@
M/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@
M("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P
M+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?
M=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@
M("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@
M("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD
M(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@
M("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@
M("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D[
M"B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L
M('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'
M5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P
M("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@
M,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F
M;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O
M7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*
M;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-
M4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]
M?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@
M(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*
M"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L
M960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*
M("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE
M8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@
M("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM
M;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*
M("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E
M<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B
M3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A
M=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT
M<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q
M=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@
M("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D
M8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M
M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>
M*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H
M9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD
M+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M
M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@
M<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*
M("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]
M"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H
M;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D
M9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@
M("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@
M("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@
M)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L
M;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*
M("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@
M;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@
M("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@
M("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME
M>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2![
M"B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*
M("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D
M969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*
M("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@
M("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R
M;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M
M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M
M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T
M("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L
M("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<
M;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D
M(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R
M;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!
M4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R
M(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@
M("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@
M("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>
M3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@
M<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@
M("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@
M("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T
M:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@
M("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U
M<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@
M(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"([
M"B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@
M07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%2
M7T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL
M960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L
M:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@
M('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V
M("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV
M;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!
M32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G
M:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@
M("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@
M87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S:&EF="!`05)'5CL*
M("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@
M("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@
M("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@
M("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@
M("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@
M("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@("`@("`@('5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@("`D;W5T(#T@)#([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@
M>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@
M("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U
M:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@
M("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D
M8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("`@("`@9&5L971E
M("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@("!I;FET7VEN8R@I
M.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@
M("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@
M("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@
M?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T
M*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/
M.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*
M("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@
M("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\
M)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@
M("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E
M860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D
M;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS
M.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[
M"B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U
M="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN
M960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE
M("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I
M92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")0
M2UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@
M(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@
M("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].
M3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@
M("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E
M9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E
M96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*
M("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[
M)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V
M86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?
M(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[
M)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*
M("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F
M.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*
M("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@
M("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*
M"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H
M)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@
M("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,[
M"@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@
M(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I
M;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*
M("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P
M97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE
M87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T
M)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T969F96X*
M("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@
M)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I
M;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R
M:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F
M;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D
M;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@
M("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@
M("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B
M*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@
M("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@
M(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O
M<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE
M.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@
M("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C
M;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@
M("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("!005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ
M<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P
M<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D[
M"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O
M=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@
M("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@
M("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@
M1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@
M("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D
M;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T
M(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L
M;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C
M86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*
M("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@
M("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M
M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM
M;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*
M(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI[
M"B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I
M>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N
M9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!0
M05(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@
M('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I
M9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN
M9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&
M:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O
M<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D
M:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H
M;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I
M;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@
M("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C
M=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@
M(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@
M("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@
M("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@
M(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N
M+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R
M96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@
M($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I
M<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I
M<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@
M=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A
M=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT
M;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ
M4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I
M9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I
M;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!
M<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2
M.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E
M=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R
M('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@
M;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!
M4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A
M<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@
M/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D
M<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@
M;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O
M97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@
M("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S
M97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM5
M4T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE
M(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#
M;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S
M=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@
M("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@
M("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@
M("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@
M("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@
M("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I
M9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U
M;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@
M("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M
M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A
M;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H
M)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%
M3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D
M:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C
M*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA
M;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL
M96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@
M?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE
M*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG
M+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@
M<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@
M:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?
M<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@
M)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*
M"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@
M("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@
M("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#
M;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA
M<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@
M("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@
M("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M
M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C
M(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@
M("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D
M0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*
M("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D
M96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G
M+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`]
M(")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@
M*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,
M14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C
M;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@
M("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*
M("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*
M?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4
M:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E
M(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE
M.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,0H*7U]%3D1?7PH`````
M1T-#.B`H56)U;G1U+TQI;F%R;R`T+C8N,BTW=6)U;G1U,2D@-"XV+C(`1T-#
M.B`H56)U;G1U+TQI;F%R;R`T+C8N,BTU=6)U;G1U,2D@-"XV+C(``"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T
M;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M``````````````````````````````````````L````!`````@`````````X
M`D```````#@"````````'`````````````````````$`````````````````
M```3````!P````(`````````5`)```````!4`@```````"``````````````
M```````$````````````````````(0````<````"`````````'0"0```````
M=`(````````D````````````````````!````````````````````#0```#V
M__]O`@````````"8`D```````)@"````````!`$````````%``````````@`
M```````````````````^````"P````(`````````H`-```````"@`P``````
M`,`)````````!@````$````(`````````!@`````````1@````,````"````
M`````&`-0```````8`T```````#M!````````````````````0``````````
M`````````$X```#___]O`@````````!.$D```````$X2````````T```````
M```%``````````(``````````@````````!;````_O__;P(`````````(!-`
M```````@$P```````(``````````!@````(````(````````````````````
M:@````0````"`````````*`30```````H!,```````"0``````````4`````
M````"``````````8`````````'0````$`````@`````````P%$```````#`4
M````````8`8````````%````#`````@`````````&`````````!^`````0``
M``8`````````D!I```````"0&@```````!@````````````````````$````
M````````````````>0````$````&`````````+`:0```````L!H```````!0
M!```````````````````$``````````0`````````(0````!````!@``````
M````'T`````````?````````Z#@``````````````````!``````````````
M``````"*`````0````8`````````Z%=```````#H5P````````X`````````
M```````````$````````````````````D`````$````"`````````/A70```
M````^%<```````!8`P``````````````````"````````````````````)@`
M```!`````@````````!06T```````%!;````````]```````````````````
M``0```````````````````"F`````0````(`````````2%Q```````!(7```
M`````"0%```````````````````(````````````````````L`````$````#
M``````````AN8```````"&X````````0````````````````````"```````
M`````````````+<````!`````P`````````8;F```````!AN````````$```
M``````````````````@```````````````````"^`````0````,`````````
M*&Y@```````H;@````````@````````````````````(````````````````
M````PP````8````#`````````#!N8```````,&X```````"P`0````````8`
M````````"``````````0`````````,P````!`````P````````#@;V``````
M`.!O````````"`````````````````````@`````````"`````````#1````
M`0````,`````````Z&]@``````#H;P```````#@"```````````````````(
M``````````@`````````V@````$````#`````````"!R8```````('(`````
M``#D6P``````````````````(````````````````````.`````(`````P``
M```````@SF````````3.````````H!```````````````````"``````````
M``````````#E`````0```#`````````````````````$S@```````%0`````
M```````````````!``````````$``````````0````,`````````````````
M````````6,X```````#N`````````````````````0``````````````````
!````
